@@ -1,9 +1,9 @@
 package Sah::Schema::date::tz_name;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-02-28'; # DATE
+our $DATE = '2020-03-03'; # DATE
 our $DIST = 'Sah-Schemas-Date'; # DIST
-our $VERSION = '0.009'; # VERSION
+our $VERSION = '0.010'; # VERSION
 
 our $schema = [str => {
     summary => 'Timezone name',
@@ -14,6 +14,9 @@ our $schema = [str => {
 
         Complete::TZ::complete_tz(word => $args{word});
     },
+    examples => [
+        {data=>'Asia/Jakarta', valid=>1},
+    ],
 }, {}];
 
 1;
@@ -32,7 +35,43 @@ Sah::Schema::date::tz_name - Timezone name
 
 =head1 VERSION
 
-This document describes version 0.009 of Sah::Schema::date::tz_name (from Perl distribution Sah-Schemas-Date), released on 2020-02-28.
+This document describes version 0.010 of Sah::Schema::date::tz_name (from Perl distribution Sah-Schemas-Date), released on 2020-03-03.
+
+=head1 SYNOPSIS
+
+Using with L<Data::Sah>:
+
+ use Data::Sah qw(gen_validator);
+ my $vdr = gen_validator("date::tz_name*");
+ say $vdr->($data) ? "valid" : "INVALID!";
+
+ # Data::Sah can also create a validator to return error message, coerced value,
+ # even validators in other languages like JavaScript, from the same schema.
+ # See its documentation for more details.
+
+Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
+
+ package MyApp;
+ our %SPEC;
+ $SPEC{myfunc} = {
+     v => 1.1,
+     summary => 'Routine to do blah ...',
+     args => {
+         arg1 => {
+             summary => 'The blah blah argument',
+             schema => ['date::tz_name*'],
+         },
+         ...
+     },
+ };
+ sub myfunc {
+     my %args = @_;
+     ...
+ }
+
+Sample data:
+
+ "Asia/Jakarta"  # valid
 
 =head1 DESCRIPTION
 
