@@ -1,5 +1,10 @@
 package Sah::Schemas::Date;
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-03-03'; # DATE
+our $DIST = 'Sah-Schemas-Date'; # DIST
+our $VERSION = '0.010'; # VERSION
+
 1;
 # ABSTRACT: Sah schemas related to date
 
@@ -15,7 +20,7 @@ Sah::Schemas::Date - Sah schemas related to date
 
 =head1 VERSION
 
-This document describes version 0.009 of Sah::Schemas::Date (from Perl distribution Sah-Schemas-Date), released on 2020-02-28.
+This document describes version 0.010 of Sah::Schemas::Date (from Perl distribution Sah-Schemas-Date), released on 2020-03-03.
 
 =head1 SYNOPSIS
 
